@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+# Copyright © 2009 Ben Finney <ben+python@benfinney.id.au>
 # Copyright © 2006 Robert Niederreiter
 #
 # This is free software: you may copy, modify, and/or distribute this work
@@ -7,4 +8,14 @@
 # later as published by the Python Software Foundation.
 # No warranty expressed or implied. See the file LICENSE.PSF-2 for details.
 
-from daemon import Daemon
+""" Library to implement a well-behaved Unix daemon process
+
+    This library implements PEP [no number yet], Standard daemon
+    process library.
+
+    """
+
+from daemon import DaemonContext
+
+
+version = "1.3"
